@@ -21,6 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define KWIN_VIRTUAL_DESKTOPS_H
 // KWin
 #include <kwinglobals.h>
+#include <kwin_export.h>
 // Qt includes
 #include <QObject>
 #include <QPoint>
@@ -32,10 +33,11 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 class KLocalizedString;
 class NETRootInfo;
+class QAction;
 
 namespace KWin {
 
-class VirtualDesktop : public QObject
+class KWIN_EXPORT VirtualDesktop : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(QByteArray id READ id CONSTANT)
@@ -62,6 +64,10 @@ public:
 
 Q_SIGNALS:
     void nameChanged();
+    /**
+     * Emitted just before the desktop gets destroyed.
+     **/
+    void aboutToBeDestroyed();
 
 private:
     QByteArray m_id;
@@ -123,7 +129,7 @@ private:
  * of an adjacent desktop or to switch to an adjacent desktop. Interested parties should make use of
  * these methods and not replicate the logic to switch to the next desktop.
  **/
-class VirtualDesktopManager : public QObject
+class KWIN_EXPORT VirtualDesktopManager : public QObject
 {
     Q_OBJECT
     /**
@@ -161,6 +167,12 @@ public:
      * @see currentChanged
      */
     uint current() const;
+    /**
+     * @returns The current desktop
+     * @see setCurrent
+     * @see currentChanged
+     **/
+    VirtualDesktop *currentDesktop() const;
     /**
      * Moves to the desktop through the algorithm described by Direction.
      * @param wrap If @c true wraps around to the other side of the layout
@@ -420,7 +432,7 @@ private:
      * @param key The global shortcut for the action
      * @param slot The slot to invoke when the action is triggered
      **/
-    void addAction(const QString &name, const KLocalizedString &label, uint value, const QKeySequence &key, void (VirtualDesktopManager::*slot)());
+    QAction *addAction(const QString &name, const KLocalizedString &label, uint value, const QKeySequence &key, void (VirtualDesktopManager::*slot)());
     /**
      * Creates an action and connects it to the @p slot in this Manager.
      * Overloaded method for the case that no additional value needs to be passed to the action and
@@ -429,7 +441,7 @@ private:
      * @param label The localized name for the action to be created
      * @param slot The slot to invoke when the action is triggered
      **/
-    void addAction(const QString &name, const QString &label, void (VirtualDesktopManager::*slot)());
+    QAction *addAction(const QString &name, const QString &label, void (VirtualDesktopManager::*slot)());
 
     QVector<VirtualDesktop*> m_desktops;
     QPointer<VirtualDesktop> m_current;
